package cn.iocoder.yudao.module.wms.controller.admin.depotarea;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Operation;

import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;

import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.wms.controller.admin.depotarea.vo.*;
import cn.iocoder.yudao.module.wms.dal.dataobject.depotarea.DepotAreaDO;
import cn.iocoder.yudao.module.wms.service.depotarea.DepotAreaService;

@Tag(name = "管理后台 - 库区管理")
@RestController
@RequestMapping("/wms/depot-area")
@Validated
public class DepotAreaController {

    @Resource
    private DepotAreaService depotAreaService;

    @PostMapping("/create")
    @Operation(summary = "创建库区管理")
    @PreAuthorize("@ss.hasPermission('wms:depot-area:create')")
    public CommonResult<Long> createDepotArea(@Valid @RequestBody DepotAreaSaveReqVO createReqVO) {
        return success(depotAreaService.createDepotArea(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新库区管理")
    @PreAuthorize("@ss.hasPermission('wms:depot-area:update')")
    public CommonResult<Boolean> updateDepotArea(@Valid @RequestBody DepotAreaSaveReqVO updateReqVO) {
        depotAreaService.updateDepotArea(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除库区管理")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('wms:depot-area:delete')")
    public CommonResult<Boolean> deleteDepotArea(@RequestParam("id") Long id) {
        depotAreaService.deleteDepotArea(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得库区管理")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('wms:depot-area:query')")
    public CommonResult<DepotAreaRespVO> getDepotArea(@RequestParam("id") Long id) {
        DepotAreaDO depotArea = depotAreaService.getDepotArea(id);
        return success(BeanUtils.toBean(depotArea, DepotAreaRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得库区管理分页")
    @PreAuthorize("@ss.hasPermission('wms:depot-area:query')")
    public CommonResult<PageResult<DepotAreaRespVO>> getDepotAreaPage(@Valid DepotAreaPageReqVO pageReqVO) {
        PageResult<DepotAreaDO> pageResult = depotAreaService.getDepotAreaPage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, DepotAreaRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出库区管理 Excel")
    @PreAuthorize("@ss.hasPermission('wms:depot-area:export')")
    @OperateLog(type = EXPORT)
    public void exportDepotAreaExcel(@Valid DepotAreaPageReqVO pageReqVO,
              HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<DepotAreaDO> list = depotAreaService.getDepotAreaPage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "库区管理.xls", "数据", DepotAreaRespVO.class,
                        BeanUtils.toBean(list, DepotAreaRespVO.class));
    }

}